---
Summary: String property after list property fails to be added to fields
Status: Done
---

# Description

If you've got a property block with list and string properties, any string
properties after the list are ignored. So:

```md
---
Summary: Summary
Tags:
    - tag 1
    - tag 2
String: Value
---
```

will not correctly set the value String

# Cucumber

**GIVEN** a property secton with string fields after list fields
**WHEN** the md file is read
**THEN** list and string fields are all read correctly
